Constant Field Values (py4j-java 0.10.0 API)
Date: 2016-04-18

# Constant Field Values

## Contents

- py4j.*

## py4j.*

- py4j.CallbackClient
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `DEFAULT_ADDRESS` | `"127.0.0.1"`
  `public static final long` | `DEFAULT_MIN_CONNECTION_TIME` | `30L`

- py4j.CallbackConnection
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `DEFAULT_NONBLOCKING_SO_TIMEOUT` | `1000`

- py4j.GatewayServer
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `DEFAULT_ADDRESS` | `"127.0.0.1"`
  `public static final int` | `DEFAULT_CONNECT_TIMEOUT` | `0`
  `public static final int` | `DEFAULT_PORT` | `25333`
  `public static final int` | `DEFAULT_PYTHON_PORT` | `25334`
  `public static final int` | `DEFAULT_READ_TIMEOUT` | `0`
  `public static final java.lang.String` | `GATEWAY_SERVER_ID` | `"GATEWAY_SERVER"`

- py4j.JVMView
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `JAVA_LANG_STAR_IMPORT` | `"java.lang"`

- py4j.Protocol
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final char` | `ARRAY_TYPE` | `116`
  `public static final char` | `BOOLEAN_TYPE` | `98`
  `public static final char` | `BYTES_TYPE` | `106`
  `public static final char` | `CLASS_TYPE` | `99`
  `public static final char` | `DECIMAL_TYPE` | `68`
  `public static final java.lang.String` | `DEFAULT_JVM_OBJECT_ID` | `"j"`
  `public static final char` | `DOUBLE_TYPE` | `100`
  `public static final char` | `END` | `101`
  `public static final char` | `END_OUTPUT` | `10`
  `public static final java.lang.String` | `ENTRY_POINT_OBJECT_ID` | `"t"`
  `public static final char` | `ERROR` | `120`
  `public static final java.lang.String` | `ERROR_COMMAND` | `"!x\n"`
  `public static final char` | `INTEGER_TYPE` | `105`
  `public static final char` | `ITERATOR_TYPE` | `103`
  `public static final char` | `LIST_TYPE` | `108`
  `public static final char` | `LONG_TYPE` | `76`
  `public static final char` | `MAP_TYPE` | `97`
  `public static final char` | `METHOD_TYPE` | `109`
  `public static final char` | `NO_MEMBER` | `111`
  `public static final java.lang.String` | `NO_SUCH_FIELD` | `"!yo\n"`
  `public static final char` | `NULL_TYPE` | `110`
  `public static final char` | `PACKAGE_TYPE` | `112`
  `public static final java.lang.String` | `PYTHON_INFINITY` | `"inf"`
  `public static final java.lang.String` | `PYTHON_NAN` | `"nan"`
  `public static final java.lang.String` | `PYTHON_NEGATIVE_INFINITY` | `"-inf"`
  `public static final char` | `PYTHON_PROXY_TYPE` | `102`
  `public static final char` | `REFERENCE_TYPE` | `114`
  `public static final char` | `RETURN_MESSAGE` | `33`
  `public static final char` | `SET_TYPE` | `104`
  `public static final java.lang.String` | `STATIC_PREFIX` | `"z:"`
  `public static final char` | `STRING_TYPE` | `115`
  `public static final char` | `SUCCESS` | `121`
  `public static final char` | `VOID` | `118`
  `public static final java.lang.String` | `VOID_COMMAND` | `"!yv\n"`

- py4j.StringUtil
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final char` | `ESCAPE_CHAR` | `92`

## py4j.commands.*

- py4j.commands.ArrayCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `ARRAY_COMMAND_NAME` | `"a"`
  `public static final char` | `ARRAY_CREATE_SUB_COMMAND_NAME` | `99`
  `public static final char` | `ARRAY_GET_SUB_COMMAND_NAME` | `103`
  `public static final char` | `ARRAY_LEN_SUB_COMMAND_NAME` | `101`
  `public static final char` | `ARRAY_SET_SUB_COMMAND_NAME` | `115`
  `public static final char` | `ARRAY_SLICE_SUB_COMMAND_NAME` | `108`
  `public static final java.lang.String` | `RETURN_VOID` | `"!yv\n"`

- py4j.commands.CallCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `CALL_COMMAND_NAME` | `"c"`

- py4j.commands.ConstructorCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `CONSTRUCTOR_COMMAND_NAME` | `"i"`

- py4j.commands.DirCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `DIR_COMMAND_NAME` | `"d"`
  `public static final java.lang.String` | `DIR_FIELDS_SUBCOMMAND_NAME` | `"f"`
  `public static final java.lang.String` | `DIR_JVMVIEW_SUBCOMMAND_NAME` | `"v"`
  `public static final java.lang.String` | `DIR_METHODS_SUBCOMMAND_NAME` | `"m"`
  `public static final java.lang.String` | `DIR_STATIC_SUBCOMMAND_NAME` | `"s"`

- py4j.commands.ExceptionCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `EXCEPTION_COMMAND_NAME` | `"p"`

- py4j.commands.FieldCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `FIELD_COMMAND_NAME` | `"f"`
  `public static final java.lang.String` | `FIELD_GET_SUB_COMMAND_NAME` | `"g"`
  `public static final java.lang.String` | `FIELD_SET_SUB_COMMAND_NAME` | `"s"`

- py4j.commands.HelpPageCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `HELP_CLASS_SUB_COMMAND_NAME` | `"c"`
  `public static final java.lang.String` | `HELP_COMMAND_NAME` | `"h"`
  `public static final java.lang.String` | `HELP_OBJECT_SUB_COMMAND_NAME` | `"o"`

- py4j.commands.JVMViewCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final char` | `CREATE_VIEW_SUB_COMMAND_NAME` | `99`
  `public static final char` | `IMPORT_SUB_COMMAND_NAME` | `105`
  `public static final java.lang.String` | `JVMVIEW_COMMAND_NAME` | `"j"`
  `public static final char` | `REMOVE_IMPORT_SUB_COMMAND_NAME` | `114`
  `public static final char` | `SEARCH_SUB_COMMAND_NAME` | `115`

- py4j.commands.ListCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `LIST_COMMAND_NAME` | `"l"`
  `public static final char` | `LIST_CONCAT_SUB_COMMAND_NAME` | `97`
  `public static final char` | `LIST_COUNT_SUB_COMMAND_NAME` | `102`
  `public static final char` | `LIST_IMULT_SUB_COMMAND_NAME` | `105`
  `public static final char` | `LIST_MAX_SUB_COMMAND_NAME` | `120`
  `public static final char` | `LIST_MIN_SUB_COMMAND_NAME` | `110`
  `public static final char` | `LIST_MULT_SUB_COMMAND_NAME` | `109`
  `public static final char` | `LIST_REVERSE_SUB_COMMAND_NAME` | `114`
  `public static final char` | `LIST_SLICE_SUB_COMMAND_NAME` | `108`
  `public static final char` | `LIST_SORT_SUB_COMMAND_NAME` | `115`
  `public static final java.lang.String` | `RETURN_VOID` | `"!yv\n"`

- py4j.commands.MemoryCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `MEMORY_COMMAND_NAME` | `"m"`
  `public static final java.lang.String` | `MEMORY_DEL_SUB_COMMAND_NAME` | `"d"`

- py4j.commands.ReflectionCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final char` | `GET_MEMBER_SUB_COMMAND_NAME` | `109`
  `public static final char` | `GET_UNKNOWN_SUB_COMMAND_NAME` | `117`
  `public static final java.lang.String` | `REFLECTION_COMMAND_NAME` | `"r"`

- py4j.commands.ShutdownGatewayServerCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `SHUTDOWN_GATEWAY_SERVER_COMMAND_NAME` | `"s"`

- py4j.commands.StreamCommand
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `STREAM_COMMAND_NAME` | `"S"`

## py4j.model.*

- py4j.model.HelpPageGenerator
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `DOUBLE_LINES` | `"\n| \n"`
  `public static final java.lang.String` | `INDENT` | `" "`
  `public static final java.lang.String` | `PREFIX` | `"|"`
  `public static final java.lang.String` | `PREFIX_INDENT` | `"| "`
  `public static final java.lang.String` | `PREFIX_SEPARATOR` | `"| ------------------------------------------------------------\n"`
  `public static final java.lang.String` | `SEPARATOR` | `"------------------------------------------------------------"`

## py4j.reflection.*

- py4j.reflection.LRUCache<K,V>
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `DEFAULT_CACHE_SIZE` | `100`

- py4j.reflection.MethodInvoker
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `INVALID_INVOKER_COST` | `-1`
  `public static final int` | `MAX_DISTANCE` | `100000000`

- py4j.reflection.PythonProxyHandler
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final java.lang.String` | `CALL_PROXY_COMMAND_NAME` | `"c\n"`
  `public static final java.lang.String` | `GARBAGE_COLLECT_PROXY_COMMAND_NAME` | `"g\n"`

- py4j.reflection.ReflectionEngine
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `cacheSize` | `100`

- py4j.reflection.TypeConverter
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `DOUBLE_TO_FLOAT` | `0`
  `public static final int` | `INT_TO_BYTE` | `2`
  `public static final int` | `INT_TO_SHORT` | `1`
  `public static final int` | `NO_CONVERSION` | `-1`
  `public static final int` | `NUM_TO_LONG` | `4`
  `public static final int` | `STRING_TO_CHAR` | `3`

- py4j.reflection.TypeUtil
  Modifier and Type | Constant Field | Value
  --- | --- | ---
  `public static final int` | `DISTANCE_FACTOR` | `100`